==> gspiceui_0.9.98.dfsg.orig.tar.gz: gspiceui-0.9.98.dfsg/src/gnucap/commands/CmdGnuCapFO.hpp <==
//*****************************************************************************
//                               CmdGnuCapFO.hpp                              *
//                              -----------------                             *
// Description : This class contains values associated with the GNU-Cap       *
//               FOURIER command. It inherits from the class CmdBase.         *
// Started     : 11/03/2008                                                   *
// Last Update : 31/07/2009                                                   *
// Copyright   : (C) 2008 by M.S.Waters                                       *
// Email       : M.Waters@bom.gov.au                                          *
//*****************************************************************************

//*****************************************************************************
//                                                                            *
//    This program is free software; you can redistribute it and/or modify    *
//    it under the terms of the GNU General Public License as published by    *
//    the Free Software Foundation; either version 2 of the License, or       *
//    (at your option) any later version.                                     *
//                                                                            *
//*****************************************************************************

#ifndef CMDGNUCAPFO_HPP
#define CMDGNUCAPFO_HPP

// System Includes

#include <iostream>
#include <climits>

// wxWidgets Includes

#include <wx/wx.h>
#include <wx/tokenzr.h>

// Application Includes

#include "base/CmdBase.hpp"
#include "utility/ConvertType.hpp"

// Local Macro and Constant Declarations


//*****************************************************************************

struct CmdGnuCapFO : public CmdBase
{
  private :

    virtual  bool  bValidate( void );

  public :

    wxString    m_osStart;  // The sweep start value
    wxString    m_osStop;   // The sweep stop  value
    wxString    m_osStep;   // The sweep step  value
    eInitCType  m_eInitC;   // The sweep scale type
    wxString    m_osTempC;  // The analysis temperature

             CmdGnuCapFO( void );
    virtual ~CmdGnuCapFO( );

    virtual  bool  bClear( void );

    virtual  bool  bParse ( void );
    virtual  bool  bFormat( void );

             void  Print( const wxString & rosPrefix=wxT("  ") );
};

//*****************************************************************************

#endif // CMDGNUCAPFO_HPP

==> gspiceui_0.9.99+dfsg.orig.tar.gz: gspiceui-0.9.99+dfsg/src/gnucap/commands/CmdGnuCapFO.hpp <==
//*****************************************************************************
//                               CmdGnuCapFO.hpp                              *
//                              -----------------                             *
// Description : This class contains values associated with the GNU-Cap       *
//               FOURIER command. It inherits from the class CmdBase.         *
// Started     : 11/03/2008                                                   *
// Last Update : 16/04/2010                                                   *
// Copyright   : (C) 2008 by M.S.Waters                                       *
// Email       : M.Waters@bom.gov.au                                          *
//*****************************************************************************

//*****************************************************************************
//                                                                            *
//    This program is free software; you can redistribute it and/or modify    *
//    it under the terms of the GNU General Public License as published by    *
//    the Free Software Foundation; either version 2 of the License, or       *
//    (at your option) any later version.                                     *
//                                                                            *
//*****************************************************************************

#ifndef CMDGCPFO_HPP
#define CMDGCPFO_HPP

// System Includes

#include <iostream>
#include <climits>

// wxWidgets Includes

#include <wx/wx.h>
#include <wx/tokenzr.h>

// Application Includes

#include "base/CmdBase.hpp"
#include "utility/ConvertType.hpp"

// Local Macro and Constant Declarations


//*****************************************************************************

struct CmdGnuCapFO : public CmdBase
{
  private :

    virtual  bool  bValidate( void );

  public :

    wxString    m_osStart;  // The sweep start value
    wxString    m_osStop;   // The sweep stop  value
    wxString    m_osStep;   // The sweep step  value
    eInitCType  m_eInitC;   // The sweep scale type
    wxString    m_osTempC;  // The analysis temperature

             CmdGnuCapFO( void );
    virtual ~CmdGnuCapFO( );

    virtual  bool  bClear( void );

    virtual  bool  bParse ( void );
    virtual  bool  bFormat( void );

             void  Print( const wxString & rosPrefix=wxT("  ") );
};

//*****************************************************************************

#endif // CMDGCPFO_HPP
